powered by
Prints the most important output of a DIFlasso object.
# S3 method for DIFlasso print(x, ...)
DIFlasso object, created by DIFlasso
DIFlasso
Further arguments to be passed to the print function.
print
Gunther Schauberger gunther.schauberger@tum https://www.sg.tum.de/epidemiologie/team/schauberger/
Tutz, Gerhard and Schauberger, Gunther (2015): A Penalty Approach to Differential Item Functioning in Rasch Models, Psychometrika, 80(1), 21 - 43
DIFlasso, plot.DIFlasso
plot.DIFlasso
if (FALSE) { data(simul.data) Y <- simul.data[,1:10] X <- simul.data[,11:13] m1 <- DIFlasso(Y = Y, X = X, trace = TRUE) print(m1) plot(m1) m2 <- refitDIFlasso(m1) print(m2) plot(m2) }
Run the code above in your browser using DataLab