Learn R Programming

DIFlasso (version 1.0-4)

print.DIFlasso.refit: Print Function for refitDIFlasso

Description

Prints the most important output of a DIFlasso.refit object.

Usage

# S3 method for DIFlasso.refit
print(x, ...)

Arguments

x

DIFlasso.refit object, created by refitDIFlasso

...

Further arguments to be passed to the print function.

References

Tutz, Gerhard and Schauberger, Gunther (2015): A Penalty Approach to Differential Item Functioning in Rasch Models, Psychometrika, 80(1), 21 - 43

See Also

refitDIFlasso, plot.DIFlasso.refit, DIFlasso

Examples

Run this code
if (FALSE) {
data(simul.data)

Y <- simul.data[,1:10]
X <- simul.data[,11:13]

m1 <- DIFlasso(Y = Y, X = X, trace = TRUE) 
print(m1)
plot(m1)

m2 <- refitDIFlasso(m1)
print(m2)
plot(m2)
}

Run the code above in your browser using DataLab