powered by
Performs the refit of a DIFlasso object. Only the items diagosed as DIF items will be used to perform a new fit of the final model.
refitDIFlasso(dif.obj)
Estimated person abilities after refit
Estimated item difficulties after refit
Estimated item-specific parameters after refit; one row per covariate, one column per item
Number of persons
Number of items
Number of covariates
Reference item
Which items have been detected to be DIF items?
Names of the items
Names of the covariates
DIFlasso object, created by DIFlasso
DIFlasso
Gunther Schauberger gunther.schauberger@tum https://www.sg.tum.de/epidemiologie/team/schauberger/
Tutz, Gerhard and Schauberger, Gunther (2015): A Penalty Approach to Differential Item Functioning in Rasch Models, Psychometrika, 80(1), 21 - 43
print.DIFlasso.refit, plot.DIFlasso.refit, DIFlasso
print.DIFlasso.refit
plot.DIFlasso.refit
if (FALSE) { data(simul.data) Y <- simul.data[,1:10] X <- simul.data[,11:13] m1 <- DIFlasso(Y = Y, X = X, trace = TRUE) print(m1) plot(m1) m2 <- refitDIFlasso(m1) print(m2) plot(m2) }
Run the code above in your browser using DataLab